0.2.3 - setup tuning
--------------------

 - more commands added to makefile
 - linting improved with isort


0.2.0 - travis ci
-----------------

 - added ci integration with travis


0.1.0 - first release
---------------------

 - first somehow working library
